****************************
Function Reference by Module
****************************

.. toctree::
   :maxdepth: 1

   reference/asset
   reference/cell_assembly_detection
   reference/conversion
   reference/cubic
   reference/current_source_density
   reference/kernels
   reference/neo_tools
   reference/pandas_bridge
   reference/signal_processing
   reference/spade
   reference/spectral
   reference/spike_train_correlation
   reference/spike_train_dissimilarity
   reference/spike_train_generation
   reference/spike_train_surrogates
   reference/sta
   reference/statistics
   reference/unitary_event_analysis

